@@ -333,7 +333,7 @@ L.Storage.DataLayersControl = L.Control.extend({
         title.innerHTML = datalayer.options.name;
     },
 
-    newDataLayer: function (e) {
+    newDataLayer: function () {
         var datalayer = this._map._createDataLayer({});
         datalayer.edit();
     }
@@ -345,13 +345,16 @@ L.Storage.DataLayer.include({
     renderToolbox: function (container) {
         var toggle = L.DomUtil.create('i', 'layer-toggle', container),
             zoom_to = L.DomUtil.create('i', 'layer-zoom_to', container),
-            edit = L.DomUtil.create('i', 'layer-edit show-on-edit', container);
+            edit = L.DomUtil.create('i', 'layer-edit show-on-edit', container),
+            table = L.DomUtil.create('i', 'layer-table-edit show-on-edit', container);
         zoom_to.title = L._('Zoom to layer extent');
         toggle.title = L._('Show/hide layer');
         edit.title = L._('Edit');
+        table.title = L._('Edit properties in a table');
         L.DomEvent.on(toggle, 'click', this.toggle, this);
         L.DomEvent.on(zoom_to, 'click', this.zoomTo, this);
         L.DomEvent.on(edit, 'click', this.edit, this);
+        L.DomEvent.on(table, 'click', this.tableEdit, this);
         L.DomUtil.addClass(container, this.getHidableClass());
         L.DomUtil.classIf(container, 'off', !this.isVisible());
     },
@@ -368,6 +371,13 @@ L.Storage.DataLayer.include({
         return 'show_with_datalayer_' + this.getLocalId();
     },
 
+    propagateRemote: function () {
+        var els = this.getHidableElements();
+        for (var i = 0; i < els.length; i++) {
+            L.DomUtil.classIf(els[i], 'remotelayer', this.isRemoteLayer());
+        }
+    },
+
     propagateHide: function () {
         var els = this.getHidableElements();
         for (var i = 0; i < els.length; i++) {
@@ -419,9 +429,9 @@ L.Storage.Map.include({
                 color.style.backgroundImage = 'url(' + symbol + ')';
             }
             L.DomEvent.on(zoom_to, 'click', function (e) {
-                this.bringToCenter(e, L.bind(this.view, this, {latlng: this.getCenter()}));
+                this.bringToCenter(e, L.bind(this.view, this));
             }, feature);
-            L.DomEvent.on(edit, 'click', function (e) {
+            L.DomEvent.on(edit, 'click', function () {
                 this.edit();
             }, feature);
             return feature_li;
@@ -607,7 +617,7 @@ L.Storage.JumpToLocationControl = L.Control.extend({
         link.href = '#';
         link.title = input.placeholder = L._('Jump to location');
         link.innerHTML = '&nbsp;';
-        var fn = function (e) {
+        var fn = function () {
             var search_terms = input.value;
             if (!search_terms) {
                 return;
@@ -635,7 +645,7 @@ L.Storage.JumpToLocationControl = L.Control.extend({
                     L.DomUtil.removeClass(link, 'loading');
                     if (data.length > 0 && data[0].lon && data[0].lat) {
                         map.panTo([data[0].lat, data[0].lon]);
-                        map.setZoom(map.options.jumpToZoom);
+                        map.setZoom(map.getOption('zoomTo'));
                     }
                     else {
                         L.S.fire('ui:alert', {content: L._('Sorry, no location found for {location}', {location: search_terms})});
