@@ -109,7 +109,7 @@ L.Util.latLngsForGeoJSON = function (latlngs) {
 };
 L.Util.CopyJSON = function (geojson) {
     return JSON.parse(JSON.stringify(geojson));
-}
+};
 L.Util.detectFileType = function (f) {
     var filename = f.name ? escape(f.name.toLowerCase()) : '';
     function ext(_) {
@@ -126,6 +126,10 @@ L.Util.detectFileType = function (f) {
     if (ext('.xml')) return 'osm';
 };
 
+L.Util.usableOption = function (options, option) {
+    return typeof options[option] !== 'undefined' && options[option] !== '' && options[option] !== null;
+};
+
 
 L.DomUtil.add = function (tagName, className, container, content) {
     var el = L.DomUtil.create(tagName, className, container);
@@ -240,9 +244,13 @@ L.Storage.Help = L.Class.extend({
         this.parentContainer = L.DomUtil.create('div', 'storage-help-container', document.body);
         this.overlay = L.DomUtil.create('div', 'storage-help-overlay', this.parentContainer);
         this.box = L.DomUtil.create('div', 'storage-help-box', this.parentContainer);
-        this.closeButton = L.DomUtil.add('a', 'storage-close-link', this.box, '&times;');
+        var closeLink = L.DomUtil.create('a', 'storage-close-link', this.box);
+        closeLink.href = '#';
+        L.DomUtil.add('i', 'storage-close-icon', closeLink);
+        var label = L.DomUtil.create('span', '', closeLink);
+        label.title = label.innerHTML = L._('Close');
         this.content = L.DomUtil.create('div', 'storage-help-content', this.box);
-        L.DomEvent.on(this.closeButton, 'click', this.hide, this);
+        L.DomEvent.on(closeLink, 'click', this.hide, this);
         L.DomEvent.addListener(this.parentContainer, 'keydown', this.onKeyDown, this);
     },
 
