@@ -46,13 +46,23 @@ L.Storage.FeatureMixin = {
         return this.datalayer && this.datalayer.isRemoteLayer();
     },
 
-    view: function(e) {
+    view: function(latlng) {
         if (this.properties._storage_options.outlink) {
             var win = window.open(this.properties._storage_options.outlink);
             return;
         }
+        if (this.map.slideshow) {
+            this.map.slideshow.current = this;
+        }
         this.attachPopup();
-        this.openPopup(e.latlng);
+        this.openPopup(latlng || this.getCenter());
+    },
+
+    openPopup: function () {
+        if (this.map.editEnabled) {
+            return;
+        }
+        this.parentClass.prototype.openPopup.apply(this, arguments);
     },
 
     edit: function(e) {
@@ -178,26 +188,19 @@ L.Storage.FeatureMixin = {
         this._redraw();
     },
 
-    usableOption: function (options, option) {
-        return typeof options[option] !== 'undefined' && options[option] !== '' && options[option] !== null;
-    },
-
     getOption: function (option, fallback) {
         var value = fallback || null;
         if (typeof this.staticOptions[option] !== 'undefined') {
             value = this.staticOptions[option];
         }
-        else if (this.usableOption(this.properties._storage_options, option)) {
+        else if (L.Util.usableOption(this.properties._storage_options, option)) {
             value = this.properties._storage_options[option];
         }
-        else if (this.datalayer && this.usableOption(this.datalayer.options, option)) {
+        else if (this.datalayer && L.Util.usableOption(this.datalayer.options, option)) {
             value = this.datalayer.options[option];
         }
-        else if (this.usableOption(this.map.options, option)) {
-            value = this.map.options[option];
-        }
         else {
-            value = this.map.getDefaultOption(option);
+            value = this.map.getOption(option);
         }
         return value;
     },
@@ -219,6 +222,10 @@ L.Storage.FeatureMixin = {
         }
     },
 
+    zoomTo: function () {
+        this.bringToCenter({zoomTo: this.getOption('zoomTo')});
+    },
+
     getNext: function () {
         return this.datalayer.getNextFeature(this);
     },
@@ -236,6 +243,16 @@ L.Storage.FeatureMixin = {
         return properties;
     },
 
+    deleteProperty: function (property) {
+        delete this.properties[property];
+        this.makeDirty();
+    },
+
+    renameProperty: function (from, to) {
+        this.properties[to] = this.properties[from];
+        this.deleteProperty(from);
+    },
+
     toGeoJSON: function () {
         return {
             type: 'Feature',
@@ -269,7 +286,7 @@ L.Storage.FeatureMixin = {
         return items;
     },
 
-    getEditContextMenuItems: function (e) {
+    getEditContextMenuItems: function () {
         return ['-',
             {
                 text: L._('Edit this feature'),
@@ -307,7 +324,7 @@ L.Storage.FeatureMixin = {
         }
     },
 
-    updateTooltipPosition: function (e) {
+    updateTooltipPosition: function () {
         if (!this.tooltip) {return;}
         this.tooltip.updatePosition(this.getCenter());
     },
@@ -363,11 +380,11 @@ L.Storage.Marker = L.Marker.extend({
             this.edit(e);
         }
         else {
-            this.view(e);
+            this.view(e.latlng);
         }
     },
 
-    _onMouseOut: function (e) {
+    _onMouseOut: function () {
         if(this.dragging && this.dragging._draggable && !this.dragging._draggable._moving) {
             // Do not disable if the mouse went out while dragging
             this._disableDragging();
@@ -443,13 +460,6 @@ L.Storage.Marker = L.Marker.extend({
         return this._latlng;
     },
 
-    openPopup: function () {
-        if (this.map.editEnabled) {
-            return;
-        }
-        L.Marker.prototype.openPopup.call(this);
-    },
-
     getClassName: function () {
         return 'marker';
     },
@@ -461,7 +471,7 @@ L.Storage.Marker = L.Marker.extend({
             'properties._storage_options.iconUrl',
             'properties._storage_options.popupTemplate',
             'properties._storage_options.zoomTo',
-            ['properties._storage_options.showLabel', {handler: 'CheckBox', helpText: L._('Add a permanent label')}]
+            'properties._storage_options.showLabel'
         ];
     },
 
@@ -488,7 +498,7 @@ L.Storage.PathMixin = {
     _onClick: function(e){
         this._popupHandlersAdded = true;  // Prevent leaflet from managing event
         if(!this.map.editEnabled) {
-            this.view(e);
+            this.view(e.latlng);
         }
     },
 
@@ -587,12 +597,20 @@ L.Storage.PathMixin = {
         return this._latlng || this._latlngs[Math.floor(this._latlngs.length / 2)];
     },
 
+    zoomTo: function () {
+        if (this.options.zoomTo) {
+            L.S.FeatureMixin.zoomTo.call(this);
+        } else {
+            this.map.fitBounds(this.getBounds());
+        }
+    },
+
     endEdit: function () {
         this.editing.disable();
         L.Storage.FeatureMixin.endEdit.call(this);
     },
 
-    _onMouseOver: function (e) {
+    _onMouseOver: function () {
         if (this.map.editEnabled && !this.editing._enabled) {
             L.Storage.fire('ui:tooltip', {content: L._('Double-click to edit')});
         }
