@@ -152,6 +152,7 @@ L.Storage.Icon.Ball = L.Storage.Icon.Default.extend({
 
 });
 
+_CACHE_COLOR = {};
 L.Storage.Icon.Cluster = L.DivIcon.extend({
     options: {
         iconSize: [40, 40]
@@ -162,13 +163,27 @@ L.Storage.Icon.Cluster = L.DivIcon.extend({
         this.cluster = cluster;
     },
 
-    createIcon: function (oldIcon) {
+    createIcon: function () {
         var container = L.DomUtil.create('div', 'leaflet-marker-icon marker-cluster'),
             div = L.DomUtil.create('div', '', container),
-            span = L.DomUtil.create('span', '', div);
+            span = L.DomUtil.create('span', '', div),
+            backgroundColor = this.datalayer.getColor(),
+            color;
         span.innerHTML = this.cluster.getChildCount();
-        div.style.backgroundColor = this.datalayer.options.color || this.datalayer.map.getDefaultOption('color');
+        div.style.backgroundColor = backgroundColor;
+        if (this.datalayer.options.cluster && this.datalayer.options.cluster.textColor) {
+            color = this.datalayer.options.cluster.textColor;
+        }
+        if (!color) {
+            if (typeof _CACHE_COLOR[backgroundColor] === "undefined") {
+                color = L.DomUtil.TextColorFromBackgroundColor(div);
+                _CACHE_COLOR[backgroundColor] = color;
+            } else {
+                color = _CACHE_COLOR[backgroundColor];
+            }
+        }
+        div.style.color = color;
         return container;
     }
 
-});
\ No newline at end of file
+});
