@@ -269,8 +269,8 @@ L.Storage.Map.include({
             delete this._controls[i];
         }
 
-        L.DomUtil.classIf(document.body, 'storage-caption-bar-enabled', this.options.captionBar || (this.options.slideshow && this.options.slideshow.delay));
-        L.DomUtil.classIf(document.body, 'storage-slideshow-enabled', this.options.slideshow && this.options.slideshow.delay);
+        L.DomUtil.classIf(document.body, 'storage-caption-bar-enabled', this.options.captionBar || (this.options.slideshow && (this.options.slideshow.delay || this.options.slideshow.autoplay)));
+        L.DomUtil.classIf(document.body, 'storage-slideshow-enabled', this.options.slideshow && (this.options.slideshow.delay || this.options.slideshow.autoplay));
         if (this.options.zoomControl) {
             this._controls.zoomControl = (new L.Control.Zoom({zoomInTitle: L._('Zoom in'), zoomOutTitle: L._('Zoom out')})).addTo(this);
         }
@@ -492,6 +492,14 @@ L.Storage.Map.include({
         return this.options['default_' + option] || null;
     },
 
+    getOption: function (option) {
+        if (L.Util.usableOption(this.options, option)) {
+            return this.options[option];
+        } else {
+            return this.getDefaultOption(option);
+        }
+    },
+
     updateExtent: function() {
         this.options.center = this.getCenter();
         this.options.zoom = this.getZoom();
@@ -576,8 +584,10 @@ L.Storage.Map.include({
         download.innerHTML = L._('Download data');
         L.DomEvent.on(download, 'click', function () {
             var type = types[typeInput.value],
-                content = type.formatter(this.toGeoJSON());
-            download.download = 'features' + type.ext;
+                content = type.formatter(this.toGeoJSON()),
+                name = this.options.name || 'data';
+            name = name.replace(/[^a-z0-9]/gi, '_').toLowerCase();
+            download.download = name + type.ext;
             window.URL = window.URL || window.webkitURL;
             var blob = new Blob([content], {type: type.filetype});
             download.href = window.URL.createObjectURL(blob);
@@ -858,7 +868,8 @@ L.Storage.Map.include({
             'zoomTo',
             'captionBar',
             'slideshow',
-            'sortKey'
+            'sortKey',
+            'showLabel'
         ], properties = {};
         for (var i = editableOptions.length - 1; i >= 0; i--) {
             if (typeof this.options[editableOptions[i]] !== 'undefined') {
@@ -986,6 +997,7 @@ L.Storage.Map.include({
             'options.dashArray',
             'options.popupTemplate',
             'options.zoomTo',
+            'options.showLabel',
             ['options.sortKey', {handler: 'Input', helpText: L._('Property to use for sorting features'), placeholder: L._('Default: name')}]
         ];
 
