@@ -14,7 +14,7 @@ L.S.Layer = {
 
     getEditableOptions: function () {return [];},
 
-    postUpdate: function (field) {}
+    postUpdate: function () {}
 
 };
 
@@ -142,12 +142,11 @@ L.Storage.DataLayer = L.Class.extend({
         displayOnLoad: true
     },
 
-    initialize: function (map, datalayer, options) {
+    initialize: function (map, data) {
         this.map = map;
         this._index = Array();
         this._layers = {};
         this._geojson = null;
-        L.Util.setOptions(this, options);
 
         var isDirty = false,
             self = this;
@@ -168,7 +167,8 @@ L.Storage.DataLayer = L.Class.extend({
         catch (e) {
             // Certainly IE8, which has a limited version of defineProperty
         }
-        this.populate(datalayer);
+        this.setStorageId(data.id);
+        this.setOptions(data);
         this.connectToMap();
         if(this.options.displayOnLoad) {
             this.show();
@@ -177,7 +177,7 @@ L.Storage.DataLayer = L.Class.extend({
             this.isDirty = true;
         }
         this.onceLoaded(function () {
-            this.map.on('moveend', function (e) {
+            this.map.on('moveend', function () {
                 if (this.isRemoteLayer() && this.options.remoteData.dynamic && this.isVisible()) {
                     this.fetchRemoteData();
                 }
@@ -193,7 +193,7 @@ L.Storage.DataLayer = L.Class.extend({
         }
 
         if (this.layer && this.options.type === this.layer._type && !force) return;
-        var visible = this.isVisible(), self = this;
+        var visible = this.isVisible();
         if (visible) {
             this.map.removeLayer(this.layer);
         }
@@ -208,6 +208,7 @@ L.Storage.DataLayer = L.Class.extend({
         if (visible) {
             this.map.addLayer(this.layer);
         }
+        this.propagateRemote();
     },
 
     eachLayer: function (method, context) {
@@ -219,7 +220,7 @@ L.Storage.DataLayer = L.Class.extend({
 
     eachFeature: function (method, context) {
         if (this.layer) {
-            this.layer.eachFeature(method, context | this);
+            this.layer.eachFeature(method, context || this);
         }
         return this;
     },
@@ -231,7 +232,7 @@ L.Storage.DataLayer = L.Class.extend({
         this.map.get(this._dataUrl(), {
             callback: function (geojson) {
                 if (geojson._storage) {
-                    this.resetOptions(geojson._storage);
+                    this.setOptions(geojson._storage);
                 }
                 if (this.isRemoteLayer()) {
                     this.fetchRemoteData();
@@ -257,7 +258,7 @@ L.Storage.DataLayer = L.Class.extend({
         this._layers = {};
         this._index = Array();
         if (this._geojson) {
-            this._geojson_bk = this._geojson;
+            this._geojson_bk = L.Util.CopyJSON(this._geojson);
             this._geojson = null;
         }
     },
@@ -311,17 +312,24 @@ L.Storage.DataLayer = L.Class.extend({
         return !this.storage_id || this._geojson !== null;
     },
 
-    populate: function (datalayer) {
+    setStorageId: function (id) {
         // Datalayer is null when listening creation form
-        if (!this.storage_id && datalayer && datalayer.id) {
-            this.storage_id = datalayer.id || null;
+        if (!this.storage_id && id) {
+            this.storage_id = id;
         }
-        L.Util.setOptions(this, datalayer);
-        this.resetLayer();
     },
 
-    resetOptions: function (options) {
-        this.options = L.Util.CopyJSON(options || {});
+    backupOptions: function () {
+        this._backupOptions = L.Util.CopyJSON(this.options);
+    },
+
+    resetOptions: function () {
+        this.options = L.Util.CopyJSON(this._backupOptions);
+    },
+
+    setOptions: function (options) {
+        L.Util.setOptions(this, options);
+        this.backupOptions();
         this.resetLayer();
     },
 
@@ -608,6 +616,7 @@ L.Storage.DataLayer = L.Class.extend({
 
     reset: function () {
         if (this.storage_id) {
+            this.resetOptions();
             if (this._leaflet_events_bk && !this._leaflet_events) {
                 this._leaflet_events = this._leaflet_events_bk;
             }
@@ -616,7 +625,6 @@ L.Storage.DataLayer = L.Class.extend({
             if (this.isRemoteLayer()) {
                 this.fetchRemoteData();
             } else if (this._geojson_bk) {
-                this.resetOptions(this._geojson_bk._storage);
                 this.fromGeoJSON(this._geojson_bk);
             }
             this._loaded = true;
@@ -666,7 +674,8 @@ L.Storage.DataLayer = L.Class.extend({
             'options.fillOpacity',
             'options.dashArray',
             'options.popupTemplate',
-            'options.zoomTo'
+            'options.zoomTo',
+            'options.showLabel'
         ];
 
         optionsFields = optionsFields.concat(this.layer.getEditableOptions());
@@ -824,6 +833,7 @@ L.Storage.DataLayer = L.Class.extend({
             features: this.isRemoteLayer() ? [] : this.featuresToGeoJSON(),
             _storage: this.options
         };
+        this.backupOptions();
         this._geojson = geojson;
         var formData = new FormData();
         formData.append('name', this.options.name);
@@ -834,7 +844,8 @@ L.Storage.DataLayer = L.Class.extend({
         this.map.post(this.getSaveUrl(), {
             data: formData,
             callback: function (data) {
-                this.populate(data);
+                this.setStorageId(data.id);
+                this.setOptions(data);
                 this.connectToMap();
                 this.reset();  // Needed for reordering features
             },
@@ -852,6 +863,12 @@ L.Storage.DataLayer = L.Class.extend({
 
     getName: function () {
         return this.options.name || L._('Untitled layer');
+    },
+
+    tableEdit: function () {
+        if (this.isRemoteLayer() || !this.isVisible()) return;
+        var editor = new L.S.TableEditor(this);
+        editor.edit();
     }
 
 });
